﻿using Newtonsoft.Json;
using SSO.Server.Code;
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Linq;
using System.Net.Http;
using System.Web;
using System.Web.Mvc;
using System.Web.Security;

namespace App1.Controllers
{
    [CheckAuth(false)]
    public class AccountController : Controller
    {
        string ssoIp = ConfigurationManager.AppSettings["SsoIp"].ToString();
        string localIp = ConfigurationManager.AppSettings["localIp"].ToString();
        public ActionResult Index()
        {
            return Redirect(string.Format("{0}/SSO/Index?ReturnUrl={1}/Account/CheckSsoTicket&LogoutUrl={1}/Account/SsoLogout", ssoIp, localIp));
        }
        /// <summary>
        /// sso登陆成功后重定向到此接口
        /// </summary>
        /// <param name="username"></param>
        /// <param name="ticket"></param>
        /// <returns></returns>
        public ActionResult CheckSsoTicket(string username, string ticket)
        {
            HttpClient _httpclient = new HttpClient();
            _httpclient.BaseAddress = new Uri(ssoIp);
            HttpResponseMessage response = _httpclient.GetAsync("SSO/CheckTicket?username=" + username + "&ticket=" + ticket).Result;
            string checkResult = response.Content.ReadAsStringAsync().Result;
            ApiResponse resp = JsonConvert.DeserializeObject<ApiResponse>(checkResult);
            if (resp.code == 0)//验证登陆成功
            {
                var loginInfo = new LoginInfo();
                loginInfo.SsoTicket = ticket;
                LoginUtils.Login(username, loginInfo);
            }
            return RedirectToAction("Index", "Home");
        }
        /// <summary>
        /// 退出接口，内部sso退出接口
        /// </summary>
        /// <returns></returns>
        public ActionResult Logout()
        {
            HttpClient _httpclient = new HttpClient();
            _httpclient.BaseAddress = new Uri(ssoIp);
            var loginInfo = LoginUtils.GetLoginInfo();
            HttpResponseMessage response = _httpclient.GetAsync(string.Format("SSO/Loginout?username={0}&ticket={1}", loginInfo.UserName, loginInfo.SsoTicket)).Result;
            string checkResult = response.Content.ReadAsStringAsync().Result;
            ApiResponse resp = JsonConvert.DeserializeObject<ApiResponse>(checkResult);
            if (resp.code == 0)//验证登陆成功
            {

            }
            return RedirectToAction("Index", "Home");
        }
        /// <summary>
        /// 供sso调用的退出接口
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        public JsonResult SsoLogout(string userName, string ticket)
        {
            LoginUtils.Logout(userName, ticket);
            return Json(new { code = 0, msg = "退出成功", data = "" }, JsonRequestBehavior.AllowGet);
        }
    }
    public class ApiResponse
    {
        public int code { get; set; }
        public string msg { get; set; }
        public object data { get; set; }
    }
}