﻿using Newtonsoft.Json;
using SSO.Server.Code;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Web;
using System.Web.Mvc;
using System.Web.Security;

namespace SSO.Server.Controllers
{
    [CheckAuth(false)]
    public class SSOController : Controller
    {
        /// <summary>
        /// 登陆页面
        /// </summary>
        /// <param name="ReturnUrl"></param>
        /// <param name="LogoutUrl"></param>
        /// <returns></returns>
        public ActionResult Index(string ReturnUrl, string LogoutUrl)
        {
            if (LoginUtils.IsLogin())
            {
                var loginInfo = LoginUtils.GetLoginInfo();
                if (!string.IsNullOrEmpty(ReturnUrl))
                {
                    LoginUtils.RegistClientInfo(loginInfo.UserName, new ClientInfo { LogoutUrl = LogoutUrl });

                    string url = string.Format("{0}?username={1}&ticket={2}", ReturnUrl, loginInfo.UserName, loginInfo.SsoTicket);
                    return Redirect(url);
                }
                else
                {
                    return RedirectToAction("Index", "Home");
                }
            }
            else
            {
                return View();
            }
        }
        /// <summary>
        /// 用户名密码验证
        /// </summary>
        /// <param name="username"></param>
        /// <param name="password"></param>
        /// <param name="logouturl"></param>
        /// <returns></returns>
        [HttpGet]
        public JsonResult CheckLogin(string username, string password, string logouturl)
        {
            //if (username == "admin" && password == "123456")
            //{
            username = "admin";
            password = "123456";
            var loginInfo = new LoginInfo();
            LoginUtils.Login(username, loginInfo);

            if (!string.IsNullOrEmpty(logouturl))
                LoginUtils.RegistClientInfo(loginInfo.UserName, new ClientInfo { LogoutUrl = logouturl });

            return Json(new { code = 0, msg = "登陆成功", data = new { user = "admin", ticket = loginInfo.SsoTicket } }, JsonRequestBehavior.AllowGet);
            //}
            //else
            //{
            //    return Json(new { code = 1, msg = "用户名或密码错误", data = "" }, JsonRequestBehavior.AllowGet);
            //}
        }
        /// <summary>
        /// 验证ticket，提供给客户端调用
        /// </summary>
        /// <param name="username"></param>
        /// <param name="ticket"></param>
        /// <returns></returns>
        [HttpGet]
        public JsonResult CheckTicket(string username, string ticket)
        {
            var loginInfo = LoginUtils.GetLoginInfo(username);
            if (ticket == loginInfo.SsoTicket)
            {
                return Json(new { code = 0, msg = "验证成功", data = "" }, JsonRequestBehavior.AllowGet);
            }
            else
            {
                return Json(new { code = 1, msg = "验证失败", data = "" }, JsonRequestBehavior.AllowGet);
            }
        }
        /// <summary>
        /// 退出，遍历所有注册的服务
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        public JsonResult Loginout(string username, string ticket)
        {
            var loginInfo = LoginUtils.GetLoginInfo(username);
            if (loginInfo != null && loginInfo.SsoTicket == ticket)//只有ticket合法了，才退出
            {
                //调用子系统登陆接口
                foreach (var client in loginInfo.Clients)
                {
                    HttpClient _httpclient = new HttpClient();
                    _httpclient.BaseAddress = new Uri(client.LogoutUrl);
                    HttpResponseMessage response = _httpclient.GetAsync("?username=" + username + "&ticket=" + ticket).Result;
                    string checkResult = response.Content.ReadAsStringAsync().Result;
                    ApiResponse resp = JsonConvert.DeserializeObject<ApiResponse>(checkResult);
                    if (resp.code != 0)//退出异常了
                    {
                        return Json(new { code = 1, msg = "退出异常", data = "" }, JsonRequestBehavior.AllowGet);
                    }
                }

                //SSO退出登录
                LoginUtils.Logout(username);
            }

            return Json(new { code = 0, msg = "退出成功", data = "" }, JsonRequestBehavior.AllowGet);
        }
    }
    public class ApiResponse
    {
        public int code { get; set; }
        public string msg { get; set; }
        public object data { get; set; }
    }
}